# number counter

A package designed to count the number of characters in a given interval for a function matplotlib.pyplot.bar . You input an array of numbers - "array" and "bin" - the number of intervals. At the output you get "counted" - the number of indexes in the interval and "interval" - an array in which your interval will be.